@@ -5,14 +5,11 @@ require_relative 'gitlab/git.rb'
 
 require_relative 'gitaly_server/client.rb'
 require_relative 'gitaly_server/utils.rb'
-require_relative 'gitaly_server/operations_service.rb'
 require_relative 'gitaly_server/repository_service.rb'
 require_relative 'gitaly_server/wiki_service.rb'
 require_relative 'gitaly_server/health_service.rb'
 require_relative 'gitaly_server/feature_flags.rb'
 
-require_relative 'praefect/transaction.rb'
-
 module GitalyServer
   STORAGE_PATH_HEADER = 'gitaly-storage-path'.freeze
   REPO_PATH_HEADER = 'gitaly-repo-path'.freeze
@@ -45,7 +42,6 @@ module GitalyServer
   end
 
   def self.register_handlers(server)
-    server.handle(OperationsService.new)
     server.handle(RepositoryService.new)
     server.handle(WikiService.new)
     server.handle(HealthService.new)
